#
# spec file for package appstream-glib
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Dominique Leuenberger, Amsterdam, The Netherlands
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _build_from_vcs 1

Name:           appstream-glib
Version:        0.5.17
Release:        2.2
Summary:        AppStream Abstraction Library
License:        LGPL-2.1+
Group:          System/Libraries
Url:            http://people.freedesktop.org/~hughsient/appstream-glib/
#Source:         http://people.freedesktop.org/~hughsient/appstream-glib/releases/%{name}-%{version}.tar.xz
Source0:        %{name}-%{version}.tar.xz
Source1:        openSUSE-appstream-process
%if %{_build_from_vcs}
BuildRequires:  gnome-common
%else
# We still need some part to build the man pages
BuildRequires:  xsltproc
%endif
BuildRequires:  gcab >= 0.6
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool >= 0.40.0
BuildRequires:  libyaml-devel
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.14
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0) >= 2.16.1
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.1.1
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libgcab-1.0)
BuildRequires:  pkgconfig(libsoup-2.4) >= 2.24
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(uuid)
Requires:       gcab
# Required in order to be able to convert .svg icons
Requires:       gdk-pixbuf-loader-rsvg
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This library provides GObjects and helper methods to make it easy to read and write AppStream metadata.
It also provides a simple DOM implementation that makes it easy to edit nodes and
convert to and from the standardized XML representation.

What this library allows you to do:

* Read and write compressed AppStream XML files
* Add and search for applications in an application store
* Get screenshot image data and release announcements
* Easily retrieve the best application data for the current locale
* Efficiently interface with more heavy-weight parsers like expat

%package -n libappstream-glib8
Summary:        AppStream Abstraction Library
Group:          System/Libraries

%description -n libappstream-glib8
This library provides GObjects and helper methods to make it easy to read and write AppStream metadata.
It also provides a simple DOM implementation that makes it easy to edit nodes and
convert to and from the standardized XML representation.

What this library allows you to do:

* Read and write compressed AppStream XML files
* Add and search for applications in an application store
* Get screenshot image data and release announcements
* Easily retrieve the best application data for the current locale
* Efficiently interface with more heavy-weight parsers like expat

%package -n libappstream-builder8
Summary:        AppStream Abstraction Library
Group:          System/Libraries

%description -n libappstream-builder8
This library provides GObjects and helper methods to make it easy to read and write AppStream metadata.
It also provides a simple DOM implementation that makes it easy to edit nodes and
convert to and from the standardized XML representation.

What this library allows you to do:

* Read and write compressed AppStream XML files
* Add and search for applications in an application store
* Get screenshot image data and release announcements
* Easily retrieve the best application data for the current locale
* Efficiently interface with more heavy-weight parsers like expat

%package -n typelib-1_0-AppStreamBuilder-1_0
Summary:        AppStream Abstraction Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-AppStreamBuilder-1_0
This library provides GObjects and helper methods to make it easy to read and write AppStream metadata.
It also provides a simple DOM implementation that makes it easy to edit nodes and
convert to and from the standardized XML representation.

%package -n typelib-1_0-AppStreamGlib-1_0
Summary:        AppStream Abstraction Library -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-AppStreamGlib-1_0
This library provides GObjects and helper methods to make it easy to read and write AppStream metadata.
It also provides a simple DOM implementation that makes it easy to edit nodes and
convert to and from the standardized XML representation.

%package devel
Summary:        AppStream Abstraction Library -- Development files
Group:          Development/Languages/C and C++
Requires:       %{name} = %{version}
Requires:       libappstream-builder8 = %{version}
Requires:       libappstream-glib8 = %{version}
Requires:       typelib-1_0-AppStreamBuilder-1_0 = %{version}
Requires:       typelib-1_0-AppStreamGlib-1_0 = %{version}
# appdata-tools was consumed into appstream-glib and is no longer maintained upstream
Obsoletes:      appdata-tools < 0.1.9
Provides:       appdata-tools = 0.1.9
# Also obsolete the -lang package; or we end up with strange conflicts
Obsoletes:      appdata-tools-lang < 0.1.9

%description devel
This library provides GObjects and helper methods to make it easy to read and write AppStream metadata.
It also provides a simple DOM implementation that makes it easy to edit nodes and
convert to and from the standardized XML representation.

What this library allows you to do:

* Read and write compressed AppStream XML files
* Add and search for applications in an application store
* Get screenshot image data and release announcements
* Easily retrieve the best application data for the current locale
* Efficiently interface with more heavy-weight parsers like expat

%package -n openSUSE-appstream-process
Summary:        Appstream processor employed by kiwi
Group:          System
Requires:       appstream-glib >= %{version}
Requires:       openSUSE-appdata-extra

%description -n openSUSE-appstream-process
A wrapper around appstream-builder, called by kiwi in order to produce AppStream metadata
for the repositories to be published

%lang_package

%prep
%setup -q

%build
%if %{_build_from_vcs}
NOCONFIGURE=1 ./autogen.sh
%endif
%configure \
    --disable-static \
    --enable-gtk-doc \
    --enable-rpm
make %{?_smp_mflags}

%install
%make_install
# We don't care for 'installed tests'; that's used by GNOME Smoke Testing.
rm %{buildroot}%{_datadir}/installed-tests/appstream-glib/*.test
find %{buildroot} -type f -name "*.la" -delete -print

# install the appstream process script to be used by kiwi
install -d -m 0755 %{_buildroot}%{_bindir}
install -m 0755 -D %{S:1} %{buildroot}%{_bindir}/$(basename %{S:1})

%find_lang %{name}

%check
if make check; then
  echo CHECKS passed
  exit 0
else
  echo CHECKS failed... dumping log file
  find -name test-suite.log -exec cat {} \;
  exit 0
fi

%post -n libappstream-glib8 -p /sbin/ldconfig

%postun -n libappstream-glib8 -p /sbin/ldconfig

%post -n libappstream-builder8 -p /sbin/ldconfig

%postun -n libappstream-builder8 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/appstream-builder
%{_bindir}/appstream-compose
%{_bindir}/appstream-util
%{_datadir}/bash-completion/completions/appstream-builder
%{_datadir}/bash-completion/completions/appstream-util
%{_libdir}/asb-plugins-5/
%{_mandir}/man1/appstream-builder.1%{?ext_man}
%{_mandir}/man1/appstream-compose.1%{?ext_man}
%{_mandir}/man1/appstream-util.1%{?ext_man}

%files -n libappstream-builder8
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libappstream-builder.so.*

%files -n libappstream-glib8
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libappstream-glib.so.*

%files -n typelib-1_0-AppStreamBuilder-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/AppStreamBuilder-1.0.typelib

%files -n typelib-1_0-AppStreamGlib-1_0
%defattr(-,root,root)
%{_libdir}/girepository-1.0/AppStreamGlib-1.0.typelib

%files devel
%defattr(-,root,root)
%{_datadir}/aclocal/appdata-xml.m4
%{_datadir}/aclocal/appstream-xml.m4
%dir %{_datadir}/gettext/its
%{_datadir}/gettext/its/appdata.*
%{_datadir}/gir-1.0/AppStreamBuilder-1.0.gir
%{_datadir}/gir-1.0/AppStreamGlib-1.0.gir
%{_datadir}/gtk-doc/html/appstream-glib/
%{_includedir}/libappstream-builder/
%{_includedir}/libappstream-glib/
%{_libdir}/pkgconfig/appstream-builder.pc
%{_libdir}/pkgconfig/appstream-glib.pc
%{_libdir}/libappstream-builder.so
%{_libdir}/libappstream-glib.so

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n openSUSE-appstream-process
%defattr(-,root,root)
%{_bindir}/openSUSE-appstream-process

%changelog
* Mon Sep 19 2016 dimstar@opensuse.org
- Update openSUSE-appstream-process: do not rename the various
  appstream files to contain the sha hash in their filename: zypp
  is not (yet) able to cope with this (boo#999047).
* Thu Sep  8 2016 dimstar@opensuse.org
- Update openSUSE-appstream-process:
  + Do not include -failed.xml.gz: people complain about the
    additional ~ 100KB zypp downloads on a repodata refresh at 'no
    value for them'. The failed.xml.gz is not needed for regular
    operations, but was a great help for packagers to find out why
    their app was vetoed. They will need to find different ways to
    get this info.
  + Rename appdata-screenshots.tar to appdata-screenshots-$HASH.tar
    to help mirrorbrain offload this file to mirrors.
* Thu Jul 14 2016 zaitor@opensuse.org
- Update to version 0.5.17:
  + trivial: post release version bump.
  + Fix gtk-doc build when builddir != srcdir.
  + Optionally use libstemmer for keyword stemming.
  + trivial: Do not include the prefix in the id-filename.
  + trivial: Disable libstemmer by default.
  + trivial: Get rid of useless internal-only gtk-doc markup.
  + trivial: Fix 'make check' without libstemmer.
  + Fall back to the country code in as_app_get_language().
  + Add an AS_STATE_PURCHASABLE constant so we can support
    purchasing apps.
  + Add an AS_STATE_PURCHASING constant.
  + monitor: Use non-deprecated glib API for monitoring renames.
  + trivial: Fix a compiler warning with libstemmer disabled.
  + store: Don't emit a warning when flatpak user directory doesn't
    exist.
  + Correct disabling of timestamps for gzip.
  + trivial: Remove the X- hack from parsing the category list.
  + Add external (X-*) keys of an app's desktop file as metadata
    AsApp.
  + Fix missing keywords in the previous commit.
  + Don't add multiple categories for apps with AudioVideo.
  + Release version 0.5.17
* Tue Jun 14 2016 dimstar@opensuse.org
- Update to version 0.5.16:
  + Add yast2-branding-openSUSE if an app depends on yast2.
  + trivial: post release version bump.
  + Fix g_ptr_array_sort use.
  + Do not rename a category ID in AsApp.
  + Never allow NULL to be added to AsApp string array.
  + Allow setting the id prefix and origin using a symlink file
    name.
  + trivial: Do not load Flatpak repos when searching.
  + Correctly detect new AppStream applications in new directories.
  + Add elementary to list of project groups.
  + trivial: Fix make distcheck.
  + trivial: Fix several issues to ensure changed signal are sent.
  + Load metainfo files if present.
  + Release version 0.5.16.
- Drop
  0001-Add-yast2-branding-openSUSE-if-an-app-depends-on-yas.patch:
  fixed upstream.
* Mon May 23 2016 dimstar@opensuse.org
- Update to version 0.5.15:
  + trivial: post release version bump.
  + Add AS_APP_QUIRK_HAS_SHORTCUT.
  + trivial: Try to shut up libasn.
  + Ignore files with invalid suffixes when building installed
    stores.
  + Add AS_APP_QUIRK_NOT_LAUNCHABLE.
  + trivial: Add three more apps to the ID fallback table.
  + trivial: Fix a critical warning when an AppData file has
    invalid input.
  + Fall back to the icon name for LOCAL icon types.
  + yaml: Make icon parser spec compliant.
  + trivial: Add a work-around for the new libreoffice in the
    builder.
  + trivial: Set missing icon prefix for cached YAML.
  + Sort archive contents by name for repeatable results.
  + Omit timestamp from gzip compressed files.
  + README.md: add note for glob usage.
  + README.md: wrap at 80 chars.
  + trivial: Add some more debugging to debug an issue.
  + Rename the xdg-app support to the new name: Flatpak.
  + trivial: Add some support for flatpak self tests.
  + Addons can have duplcate names.
  + Show the app name when complaining about missing description in
    the metadata.
  + Revert "trivial: Add some support for flatpak self tests".
  + Always add /var/lib/flatpak/appstream as a possible Flatpak
    path.
  + Add all applications for all architectures when loading
    Flatpak.
  + Set the architecture of discovered Flatpak apps.
  + Correctly set the architecture on newly discovered
    applications.
  + Save the ID prefix in more places.
  + Release version 0.5.15.
- Drop 0001-Omit-timestamp-from-gzip-compressed-files.patch and
  0001-Sort-archive-contents-by-name-for-repeatable-results.patch:
  fixed upstream.
* Thu May 19 2016 hpj@suse.com
- Update to GNOME 3.20.2 (FATE#318572).
* Tue May  3 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon May  2 2016 stefan.bruens@rwth-aachen.de
- Make output of appstream-builder repeatable (boo#977885):
  + 0001-Sort-archive-contents-by-name-for-repeatable-results.patch
  + 0001-Omit-timestamp-from-gzip-compressed-files.patch
* Tue Apr 26 2016 zaitor@opensuse.org
- Update to version 0.5.14:
  + Ignore desktop files with X-AppStream-Ignore.
  + Add search-pkgname to appstream-glib.
  + Add AS_APP_QUIRK_NEEDS_REBOOT.
  + Fall back to searching in as_store_get_app_by_pkgname().
  + Add AS_APP_QUIRK_NOT_REVIEWABLE.
  + Search /usr/share/metainfo for local files.
  + trivial: Fix critical warning when validing broken AppStream
    files.
  + Add the Audio+Video categories from AppStream XML too.
  + Add as_screenshot_get_image_for_locale().
* Thu Apr 14 2016 dimstar@opensuse.org
- Require the main-package by the -devel package: the AS-utils are
  expected to be available to a developer.
* Mon Apr  4 2016 dleuenberger@suse.com
- openSUSE-appstream-process: No longer pass --api-version to the
  appstream-builder call (boo#973385).
* Sat Apr  2 2016 zaitor@opensuse.org
- Update to version 0.5.13:
  + trivial: post release version bump
  + Also filter YAML apps before adding to the store
  + trivial: Fix a gtk-doc markup warning
  + Support more DEP11 YAML markup
  + Always veto anything with X-Unity-Settings-Panel
  + Use a wildcard for the font preview checksum
  + Enforce the requirement of AppData for
    'Categories=DesktopSettings'
  + Add as_store_remove_apps_with_veto()
  + trivial: Only remove apps with a veto when specified
  + Do not hardcode x86_64 when searching for xdg-app metadata
  + Release version 0.5.13
* Sat Apr  2 2016 zaitor@opensuse.org
- Update to version 0.5.12:
  + trivial: post release version bump
  + trivial: Add missing gtk-doc
  + Add support for content ratings
  + trivial: Add some more OARS CSM ages
  + Split up AudioVideo into two categories
  + Add as_app_get_id_no_prefix()
  + Add AS_APP_QUIRK_MATCH_ANY_PREFIX
  + Add as_store_get_app_by_id_ignore_prefix()
  + Add as_store_get_apps_by_id()
  + Merge duplicate AppStream component entries
  + Add as_app_has_compulsory_for_desktop()
  + Add a merge-appstream command to appstream-util
  + Release version 0.5.12
* Tue Mar  8 2016 dimstar@opensuse.org
- Update to version 0.5.11:
  + trivial: post release version bump
  + trivial: Do not require icons for generic component types.
  + Fix ordering of parameters to as_store_search_app_info.
  + Add AS_APP_KIND_LOCALIZATION.
  + Fix crash when validating files containing invalid remote URIs.
  + Add as_markup_import()
  + Add support for GNOME Shell extensions..
  + Do not tokenize the application ID or package name.
  + trivial: When searching look in the user app-info dirs too.
  + Do not mark all subsumed applications as installed.
  + trivial: Fix FALSE/NULL confusion spotted with GCC6.
  + trivial: Fix a tiny introspection warning.
  + trivial: Fix another compile warning with GCC6.
  + Add a AsMarkupConvertFormat to as_markup_import().
  + Split out as-markup into a new source file.
  + Add as_utils_string_replace().
  + trivial: Prefer <ul> over <ol> when the list start is unknown.
  + Support importing HTML text using as_markup_import().
  + Add a 'markup-import' command to appstream-util for testing
    text import.
  + Implement DEP-11 MediaBaseUrl support.
  + Tokenize names like 'half-life' into two tokens for searching.
  + Release version 0.5.11.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 0.5.10:
  + Add AS_APP_KIND_SHELL_EXTENSION.
  + Add AS_APP_KIND_OS_UPDATE.
  + trivial: Display the search sort key in hex.
  + Do not tokenize mimetypes.
  + Support loading XML files using as_store_from_bytes().
  + trivial: Fix critical warning for xdg-app bundles.
  + Add AsAppQuirk.
  + trivial: Add AS_APP_QUIRK_HAS_SOURCE.
  + Add a 'split-appstream' command to appstream-util.
  + Release version 0.5.10.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 0.5.9:
  + trivial: post release version bump
  + Fix dates in NEWS - It's 2016!
  + Add missing G_BEGIN_DECLS in libappstream-glib/as-tag.h.
  + Accept FSFAP as a valid metadata license
  + Update the SPDX license list
  + Fix a validation error for metainfo files with descriptions
  + store: Keep track of which appinfo dirs are added and never
    re-add them
  + store: Pick up newly added appinfo dirs for xdg-app remotes
  + trivial: Fix a couple of small memory leaks
  + Release version 0.5.9
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 0.5.8:
  + trivial: post release version bump
  + trivial: Remove the hardcoded hack for nautilus
  + trivial: Remove some dead code
  + trivial: Remove a warning for no recent upstream release
  + trivial: Remove the veto for ConsoleOnly
  + Use the project_group heuristics when parsing AppData files
  + Remove the hardcoded rule for xfdashboard as it has been
    reported upstream
  + Only load supported icon kinds when using appstream-compose
  + trivial: Remove support for old-style firmware GUIDS-as-IDs
  + trivial: Relax the XML header requirement
  + Reject an invalid project group when parsing
  + Use heuristics when building metadata with an AppData file
  + trivial: Fix linking error when building appstream-compose
  + Add support for per-user and system-wide xdg-app installed
    stores
  + Set the xdg-app origin using the filename
  + Add a modify command to appstream-util
  + trivial: Add the missing AsBundle to gtk-doc
  + Add AsTranslation to support <translation> tags in AppData
    files
  + Fix a regression in the icon_path logic from the xdg-app merge
  + Support multi-line copyright statements
  + Allow setting state on AsRelease objects
  + Support the QT translation system
  + Parse the sections in the QM file format
  + trivial: Fix regression with AppStream metadata in xmls
  + Add support for the GENERIC component kind
  + Add a flag for skipping invalid AppStream files
  + Remove support for Ubuntu app-install data
  + Set the xdg-app origin on the store, and only set app origin to
    the remote name
  + trivial: Fix up self tests after generic kind
  + Move the kudo and provides autodetection to libappstream-glib
  + Use predictable sorting when outputting <provides>
  + trivial: Do not require icons for generic or runtime kinds
  + Show the source of the 'appstream-util check-root' failure
  + Do not respect the icon_root when using as_store_from_file()
  + Blacklist the xdg-app AppStream data as the correct data is
    added manually
  + trivial: Support loading the xdg-app AppStream data from inside
    the sandbox
  + trivial: Prefer the xmls icon rule over the xdg-app one
  + dep11: Support stock icons
  + Escape data before writing to an HTML file
  + Ignore temp and hidden files in AsMonitor
  + Release version 0.5.8
* Sat Feb  6 2016 dimstar@opensuse.org
- openSUSE-appstream-process: fix very stupid typo. 4 eyes is not
  enough.
* Fri Jan 29 2016 dimstar@opensuse.org
- openSUSE-appstream-process: use specific temporary/cache
  directories between calls. Otherwise, icons extracted from a
  previous run bleed into the next one.
* Fri Jan 29 2016 dimstar@opensuse.org
- Update to version 0.5.7:
  + trivial: post release version bump.
  + Detect web-apps which are added as .desktop files.
  + Make the check for screenshot equality more robust.
  + trivial: Fix self tests after the xdg-app fixes.
  + trivial: Never write empty <screenshot/> tags.
  + Move the blacklisted application list to the front-end client.
  + ostree: Work around threadsafety issue with
    g_get_language_names.
  + ostree: Remove unnecessary workarounds for bundle paths.
  + Move the gettext parsing to libappstream-glib.
  + trivial: Use G_DEFINE_QUARK.
  + Only build the test firmware files when using
  - -enable-firmware.
  + Allow disabling font support with --disable-fonts.
  + Allow multiple NLS domains to be specified when searching.
  + Add as_image_load_filename_full().
  + Support date=iso8601 attributes in <release> markup.
  + Add appstream-compose.
  + Remove all traces of ostree.
  + Remove the GStreamer plugin.
  + Remove the GIR and GResource, nm and KDE-specific plugins.
  + trivial: Fix 'make distcheck' with the new gettext test files.
  + trivial: Fix building firmware after the ostree removal.
  + Release version 0.5.7.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 0.5.6:
  + trivial: post release version bump.
  + Accept various 'or later' metadata content licenses.
  + libappstream-glib: Add the runtime ID kind.
  + trivial: Fix a small memory leak when parsing debs.
  + Assume a release value of '0' when unset.
  + Fix AppStream generation when using duplicate .deb packages.
  + Check the project_group when validating.
  + Check name uniqueness when validating AppStream data.
  + trivial: Mark some more strings as translatable.
  + Install gettext ITS rules.
  + Cull the application blacklist now we depend on AppData files
    for the builder.
  + trivial: Add the gettext files to the example spec file.
  + Set a validation failure for files using <updatecontact> when
    being strict.
  + Allow dumping inf files using appstream-util.
  + trivial: Fix the Since: value on as_utils_is_spdx_license().
  + Always blacklist desktop files for uninstalling software.
  + Automatically add missing .inf types as required.
  + trivial: Fix the self tests after the blacklist cull.
  + Prefer stock icons when using as_app_get_icon_default().
  + package-ostree: Init NEVRA on open otherwise we don't get the
    right tmpdir name.
  + asb-package-ostree: Fix things up for xdg-app use.
  + ostree: Allow specifying a particular arch only.
  + Release version 0.5.6.
* Sun Dec 20 2015 zaitor@opensuse.org
- Update to version 0.5.5:
  + Add a AS_APP_STATE_UPDATABLE_LIVE constant so we can support
    live updates.
  + Allow update_contact to be output in very limited conditions.
  + Log when we auto-add kudos or keywords.
  + Add the package name as another application search token.
  + Add as_utils_license_to_spdx().
  + Only use the package license when not provided by the AppData
    file.
  + trivial: Fix a compiler warning.
  + Fix a crash when tokenizing a NULL string.
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 0.5.4:
  + New Features: Add as_utils_version_from_uint16().
  + Bugfixes: Generate GUID values according to RFC4122.
- Add pkgconfig(uuid) BuildRequires: New dependency.
* Tue Nov 17 2015 dimstar@opensuse.org
- Update to version 0.5.3:
  + trivial: post release version bump.
  + trivial: Sync example spec file with downstream.
  + Strip Win32 and Linux paths when decompressing firmware.
  + Return the correct error when the desktop file has no
    [Desktop Entry] group.
* Tue Nov 17 2015 dimstar@opensuse.org
- openSUSE-appstream-process: Do not produce html files;
  the biggest chunks of apps are done and the few users still
  caring can produce them anytime out of the provided .xml.gz
  files.
* Sat Nov  7 2015 zaitor@opensuse.org
- Add pkgconfig(libgcab-1.0) BuildRequires: New dependency.
* Mon Nov  2 2015 dimstar@opensuse.org
- Update to version 0.5.2:
  + Do not overwrite the AppData URL with the one from the package.
  + Do not ever store the KDE x-test locale data.
  + Require AppData files to be present in the AppStream metadata.
  + Use a sensible warning when processing desktop files with
    NoDisplay=true.
  + Simplify veto messages for missing <name> and <summary>.
  + Fix a typo in command name.
  + Support super-HiDPI icons like shipped in Hedgewars.
  + trivial: Do not subsume vetos if AS_APP_SUBSUME_FLAG_PARTIAL is
    used.
  + Accept a '0x' hexidecimal prefix when parsing a component.
  + Always use a dotted-decimal representation of the version.
  + Add AsProfile for speed profiling.
  + trivial: Show the path when profiling
    as_store_load_installed().
  + as_profile: Non-void function should return a value.
  + trivial: Symbolic stock icons are valid.
  + Add an --enable-profile option to appstream-util.
  + Remove the long-obsolete appdata-validate tool.
  + Add as_profile_set_autodump().
  + Monitor /usr/share/applications for apps without AppData when
    using watch flags.
  + Add as_markup_validate() to check descriptions.
  + Allow as_markup_convert() to ignore errors.
  + Always escape AppStream descriptions when doing passthrough.
  + Add support for <size>.
  + Add the ability to attach blobs of data to AsRelease objects.
  + Add the ability to parse .cab archives as AppStream stores.
  + Use AsStoreCab to read .cab files when building metadata.
  + Fix crash in validator when processing '<li></li>'.
  + Do not fail to install firmware if DriverVer is not set.
  + Use as_utils_vercmp() to be correctly check versions for
    equality.
  + Try harder to deal with icons that have extension or full path
    listed.
  + Only accept UNIX paths for files in cab files.
  + Do not use the DriverVersion for the inf file version.
  + Use a MS-style version number when parsing a hex version.
  + libappstream-glib: Do not parse ISO dates as uint32 version
    numbers.
  + Do not attempt to parse the version in
    as_release_set_version().
  + Use a wildcard in the self tests to ignore GCab-generated hash
    differences.
* Wed Sep 16 2015 opensuse-packaging@opensuse.org
- Update to version 0.5.1:
  + trivial: post release version bump
  + Do not blacklist the 'desktop' token as this is sometimes
    legitimate
  + Support SPDX IDs with the LicenseRef prefix
  + Support the SPDX 'NONE' and 'NOASSERTION' keywords
  + trivial: Fix build warning in make check
  + trivial: Fix a build error when running under ninja
  + trivial: Remove prototype with no method
  + Allow a filter filename to be used with the builder
  + Introduce _cleanup_free_libc_ cleanup attribute
  + Avoid using PATH_MAX
  + Revert "Allow a filter filename to be used with the builder"
  + Ignore empty AppStream XML files
  + Add a few KDE applications that have changed desktop ID
  + Don't show mangled version numbers as negatives
  + Add another GNOME application that changed IDs
  + libappstream-glib: Port to G_DECLARE_DERIVABLE_TYPE macro
  + libappstream-builder: Port to G_DECLARE_DERIVABLE_TYPE macro
  + Use GLib's cleanup functions instead of libgsystem's
  + trivial: Fix the build
  + trivial: Remove any support for installed appdata-extra files
  + trivial: Drop as-cleanup.h include where not needed
  + Do not fail to validate firmware in AppStream with no
    screenshots
  + Use glib's cleanup functions for libsoup as well
  + Use glib's cleanup functions for GString
  + Add support for release urgency
  + Don't reallocate malloc'd memory with g_malloc
  + Use specific types to remove the last _cleanup_free usage
  + Use the typedef'd name in the code to help readability
  + trivial: Fix --enable-ostree build
  + trivial: Fix gcab generated checksums
  + Release version 0.5.1
* Tue Sep  1 2015 dimstar@opensuse.org
- openSUSE-appstream-process: compress the status html files
  (boo#942985).
* Thu Aug 13 2015 zaitor@opensuse.org
- Update to version 0.5.0:
  + Show a better error message when there's not enough text
    before <ul>.
  + Add two functions from fwupd for checking GUID strings.
  + Fix the name of the D-Bus session enum.
  + trivial: Remove unused prototype.
  + Add support for the flashed firmware provide kind.
  + Find the application in a store by the provide value.
  + trivial: Do not run the slow GFileMonitor tests by default.
  + Remove support for lower than AppStream 0.8.
  + Remove an unused exported method.
- Rename libappstream-builder7 to libappstream-builder8 and
  libappstream-glib7 to libappstream-glib8, following upstreams
  soname change.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 0.4.1:
  + New Features:
  - Add a 'compare' command to appstream-util.
  - Add a 'mirror-local-firmware' command to appstream-util.
  - Add a flag to relax the AppData Category=Settings
    requirement.
  - Add a flag to use non-optimal data sources when building
    metadata.
  - Add am 'incorporate' command to appstream-util.
  - Add two flags to veto-ignore to relax the requirements for
    metadata.
  + Bugfixes:
  - Be less strict when loading incorrect AppData files.
  - Do not duplicate <location> tags within a release.
  - Do not expect the INF ClassGuid to be the ESRT GUID.
  - Don't crash when parsing a <release> with no description.
  - Fix a potential crash spotted by clang.
  - Fix autogen with latest Intltool.
  - Ignore the prefix when loading system-wide AppStream
    information.
  - Include <pkgname> when writing the ignored metadata.
  - Only write the release timestamp if non-zero.
  - Remove the AppData veto when incorporating metadata.
  - Search harder when using AS_ICON_LOAD_FLAG_SEARCH_SIZE.
  - Sort multiple <icon> entries by name.
  - Update the SPDX licence list to v2.0.
  - When building metadata with the use-fallback flag accept
    legacy icon names.
* Mon Jul 13 2015 dimstar@opensuse.org
- Failing the test suite is not fatal.
* Wed May 27 2015 dimstar@opensuse.org
- Update to version 0.4.0:
  + Version the builder plugin location.
  + Show a warning when the origin or basename isn't specified.
  + Do not use the cache location when using install-origin with a
    DESTDIR.
  + Release version 0.4.0.
* Mon May 11 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150506:
  + trivial: Set the catalog basename as additional metadata.
  + Remove overzealous blacklisting entry.
  + Detect recolorable symbolic icons.
  + Fix exo-web-browser blacklist entry.
  + Add text icons and sample text for some languages.
  + Have another go at fixing font previews.
* Wed Apr 22 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150414:
  + trivial: post-branch version bump
  + Use the sanitized font filename as the cache-id
  + trivial: Never attempt to mirror generated screenshots
  + Check for duplicate screenshots when adding fonts
  + trivial: Convert the porting document to markdown
* Fri Apr 10 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150409:
  + Fix a crash for an invalid AppData file
* Tue Apr  7 2015 dimstar@opensuse.org
- Move openSUSE-appstream-process definition from
  libzypp-plugin-appdata to appstream-glib: as appstream-glib
  provides the actual code, it's much easier to update the
  openSUSE-appstream-process script in the same package.
* Tue Apr  7 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150407:
  + trivial: post release version bump.
  + Build: link libasb_plugin_font.la with GTK3.
  + Allow using as_node_get_localized_unwrap() on unwrapped
    description markup.
  + Remove --extra-appstream from the builder.
  + No longer set PaddedIcon.
  + trivial: Remove some unused code.
  + Add a mirror-screenshots command to appstream-util
  + Remove all networking support when building metadata.
  + Remove the extra screenshots and appdata options from the
    builder.
  + Remove the batch output option from the builder.
  + Do not strip out the source screenshot when using
    mirror-screenshots --nonet.
- Drop appstream-glib-cairo-link.patch: fixed upstream.
* Mon Mar 30 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.6:
  + trivial: post release version bump.
  + trivial: Make the UTF-8 test actually match the comment.
  + Also subsume application licenses.
  + Do not fail due to style warnings when using relaxed
    validation.
  + Add --batch-output to be able to disable the progress panel
    when building.
  + configure.ac: gcab is a hard requirement.
  + Remove the gtk3 dep from libappstream-glib.
  + configure.ac: fix typo.
  + Use the correct image URL for HiDPI screenshots.
  + Allow uninstalling AppStream files from /var/cache.
  + Use the upstream screenshot when we are using appstream-builder
  - -no-net.
  + Make the AppStream builder support optional.
  + Assume the INF DriverVer is UTC.
  + Always upscale screenshots if they are too small.
  + Teach asb_utils_write_archive() how to write other archive
    formats.
  + Put all the screenshots in a file rather than just writing to
    the upload path.
  + If the API version is unspecified when building use the latest
    released version.
  + Add the source-only tags when outputting AppData files.
  + Add a 'replace-screenshots' command to appstream-util.
  + Update the checksums for the gcab-generated firmware.
  + Do not trust the result of FcConfigAppFontAddFile().
  + Release version 0.3.6.
- Drop appstream-glib-uninstall-var-cache.patch: fixed upstream.
- Add appstream-glib-cairo-link.patch: link the font plugin to
  cairo and gtk3.
* Fri Mar 20 2015 dimstar@opensuse.org
- Add appstream-glib-uninstall-var-cache.patch: also remove
  appstream metainfo installed to /var/cache.
- Add
  0001-Add-yast2-branding-openSUSE-if-an-app-depends-on-yas.patch:
  Mark yast2 as a meta-package bringing a set of icons for other
  packages to depend on.
* Tue Mar 17 2015 dimstar@opensuse.org
- Add gdk-pixbuf-loader-rsvg Requires: needed, in order to be able
  to convert .svg icons to pixmaps.
* Fri Mar 13 2015 dimstar@opensuse.org
- Update to version 0.3.5:
  + New Features:
  - Add new API required for firmware support.
  - Add new API required for OSTree and xdg-app support.
  - Add 'news-to-appdata' and 'appdata-to-news' cmds to
    appstream-util.
  - Support all of the yet-unreleased AppStream 0.9 spec.
  + Bugfixes:
  - Add releases from the upstream AppData files.
  - Allow short descriptions when validating <description> in
    releases.
  - Correctly load descriptions from <releases> in AppData files.
  - Fix a builder crash where a package depends on itself.
  - Fix a crash when more than one thread tries to ensure the
    same package.
  - Fix DSO Linking error when built with --as-needed.
  - Make the failed AppStream metadata optional.
  - Make the icon tarball optional.
  - Relax validation checks to allow empty release sections.
  - Return the correct exit code from appstream-builder.
- Add gcab BuildRequires and Requires: needed for the cab
  extraction of the new Firmware support.
* Wed Jan 28 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.4:
  + Allow specifying --packages-dir multiple times
  + Show the offending text when validation fails
  + Do not blacklist applications with broken AppData files
  + Remove the composite plugin
  + Add as_app_get_search_tokens()
  + Add show-search-tokens subcommand to appstream-util
  + Do not store short search tokens like 'a' and 'or'
  + trivial: Do not store search tokens with markup
  + Blacklist the 40 most common search tokens
  + Check if the search entries are valid before searching
  + Accept <metadata_licence> as a fallback for <metadata_license>
  + trivial: Fix 'make distcheck' now the composite plugin has gone
  + Release version 0.3.4
* Mon Jan  5 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.1.git.20150103.a7941d7:
  + Assume that stock icons are available in HiDPI sizes.
  + Blacklist the IBus desktop files used in gnome-control-center.
  + Add several more non-applications to the blacklist.
  + Blacklist KDE3 KCM components.
  + Assume <image>foo</iimagemg> is a source image kind for AppData
    files.
  + trivial: Support ASB_PACKAGE_ENSURE_VCS for RPM packages.
  + Handle other-endian MO files.
  + trivial: Add 4 more stock icons to the whitelist.
  + Fall back to the dumb tokenizer for keywords with special
    chars.
* Wed Dec 24 2014 dimstar@opensuse.org
- Also obsolete appdata-tools-lang to facilitate updates.
* Fri Oct 31 2014 dimstar@opensuse.org
- Update to 0.3.1.git.20141031:
  + Fix make check run in chroot.
  + Merge appdata-validate.
- Enable make check.
- Obsolete and provide appdata-tools by the -devel package:
  appdata-tools has been merged into appstream glib and the
  resulting binary is shipped in our -devel package.
* Thu Oct 30 2014 dimstar@opensuse.org
- Update to 0.3.1.git.20141030.7a5f76a:
  + No longer trip over extracting hardlinked files.
* Thu Oct 23 2014 dimstar@opensuse.org
- Update to version 0.3.1.git.20141023.f8bf1b6:
  + Allow to disable some vetos.
* Wed Oct 22 2014 dimstar@opensuse.org
- Update to version 0.3.1:
  + Add a kudo for a HiDPI ico.
  + Add an --enable-hidpi argument to appstream-builder.
  + New  APIs: AS_APP_VALIDATE_FLAG_ALL_APPS,
    asb_app_set_hidpi_enabled(), asb_context_get_min_icon_size(),
    asb_context_set_embedded_icons(), as_icon_convert_to_kind(),
    as_node_add_attribute_as_int(), as_screenshot_set_priority(),
    as_store_convert_icons(), as_utils_find_icon_filename_full()
    and as_utils_get_string_overlap().
  + Add AsIcon as a new abstract icon object.
  + Add AS_ICON_KIND_EMBEDDED and AS_ICON_KIND_LOCAL.
  + Alpm backend for appstream-builder.
  + Support filtering by metadata in status-csv.
  + Many bugfixes.
- Disable _build_from_cvs, as this is a released tarball again.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 0.3.0.git.20141013.6d59429:
  + Allow to merge icons into appstream xml. Comes in handy for
    OBS, where we generate an appstream with embedded icons.
- Add gobject-introspection-devel BuildRequires: dependency to
  bootstrap the tarball.
- Add conditional (based on _build_from_vcs defines) gnome-common
  BuildRequires and call to autogen.sh: needed, as we are currently
  packaging a git snapshot.
- Add libyaml-devel BuildRequires: new dependency.
- Split new subpackages typelib-1_0-AppstreamBuilder-1_0 and
  typelib-1_0-AppstreamGlib-1_0.
- Rename libappstream-builder1 to libappstream-builder7 and
  libappstream-glib1 to libappstream-glib7, following upstreams
  soname change.
* Wed Oct  8 2014 dimstar@opensuse.org
- Update to version 0.2.6:
  + Add a veto if a .desktop file has NoDisplay=true.
  + Add more things to the blacklist that are not applications.
  + A keyword search match is better than the project name.
  + Turn of sig checking for rpm packages.
  + Update the SPDX license list to v1.20.
- Changes from version 0.2.5:
  + New Features:
  - Add an installed test for the destdir-check.
  - Add as_app_add_veto().
  - Add AS_APP_PARSE_FLAG_ALLOW_VETO.
  - Add AS_STORE_LOAD_FLAG_ALLOW_VETO.
  - Add as_store_remove_all().
  - Add as_store_set_builder_id().
  - Add as_utils_find_icon_filename().
  - Add as_utils_is_spdx_license().
  - Add as_utils_spdx_license_detokenize().
  - Add check-root to appstream-util.
  - Add some validation rules for metainfo files.
  + Bugfixes:
  - Allow desktop->addon demotion with an AppData file.
  - Allow different source roots to define addons.
  - Do not require sentence case when validating with relaxed
    settings.
  - Fix up legacy license IDs when tokenizing.
  - Ignore localized keywords.
  - Ignore localized screenshots.
  - Link client/appstream-util against gdk-pixbuf.
  - Metadata licenses like 'CC0 and CC-BY-3.0' are valid content
    licenses.
  - Never add duplicate <extends> tags.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 0.2.4:
  + New Features:
  - Add AS_PROVIDE_KIND_DBUS_SYSTEM.
  - Add an 'install-origin' command to appstream-util.
  - Add an installed tests to validate appdata.
  - Add as_store_set_destdir() so we can use a different root.
  - Add as_store_validate().
  - Add asb_app_set_veto_description().
  - Add support for <source_pkgname> which will be in
    AppStream 0.8.
  - Add the <dbus> provide for applications automatically.
  + Bugfixes:
  - Add a plugin to detect new-style 'gtk/menus.ui' AppMenu
    support.
  - Avoid using rsync's -a parameter.
  - Detect any addons with missing parents.
  - Do not load applications with NoDisplay=true when loading
    local.
  - Do not pad the compressed AppStream metadata with NUL bytes.
  - Do not treat app-install metadata as installed.
  - Markup errors should not be fatal when assembling a store.
  - Only add registered projects and categories to the metadata.
  - Only link to apps.fedoraproject.org when processing Fedora
    metadata.
  - Show the time remaining when building metadata.
  - Show what application addons extend in status.html.
  - Validate for a sentence case start in <p>, <li> and <name>
    tags.
- Changes from version 0.2.3:
  + New Features:
  - Add some simple filtering in the status.html page.
  - Record if distro metadata and screenshots are being used.
  - Show the builder progress in a ncurses-style panel.
  - Support pre-decompressed RPMs.
  + Bugfixes:
  - Add oxygen-icon-theme when an application depends on
    kde-runtime.
  - Be more careful with untrusted XML data.
  - Do not allow duplicates to be added when using
    as_app_add_kudo_kind().
  - Do not fail to build packages with invalid KDE service files.
  - Do not warn if the AppData file duplicates the .desktop
    value.
  - Show any package duplicates when generating metadata.
  - Show apps with missing icons in the failed metadata.
* Mon Jul 14 2014 dimstar@opensuse.org
- Pass --enable-rpm to configure: we DO want to support RPMs.
- Add pkgconfig(rpm) BuildRequires: required for RPM support.
* Sat Jul 12 2014 dimstar@opensuse.org
- Initial package, version 0.2.2.
